/*******************************************************************************
* File Name: pwmop.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_pwmop_H) /* Pins pwmop_H */
#define CY_PINS_pwmop_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "pwmop_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 pwmop__PORT == 15 && ((pwmop__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    pwmop_Write(uint8 value);
void    pwmop_SetDriveMode(uint8 mode);
uint8   pwmop_ReadDataReg(void);
uint8   pwmop_Read(void);
void    pwmop_SetInterruptMode(uint16 position, uint16 mode);
uint8   pwmop_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the pwmop_SetDriveMode() function.
     *  @{
     */
        #define pwmop_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define pwmop_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define pwmop_DM_RES_UP          PIN_DM_RES_UP
        #define pwmop_DM_RES_DWN         PIN_DM_RES_DWN
        #define pwmop_DM_OD_LO           PIN_DM_OD_LO
        #define pwmop_DM_OD_HI           PIN_DM_OD_HI
        #define pwmop_DM_STRONG          PIN_DM_STRONG
        #define pwmop_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define pwmop_MASK               pwmop__MASK
#define pwmop_SHIFT              pwmop__SHIFT
#define pwmop_WIDTH              1u

/* Interrupt constants */
#if defined(pwmop__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in pwmop_SetInterruptMode() function.
     *  @{
     */
        #define pwmop_INTR_NONE      (uint16)(0x0000u)
        #define pwmop_INTR_RISING    (uint16)(0x0001u)
        #define pwmop_INTR_FALLING   (uint16)(0x0002u)
        #define pwmop_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define pwmop_INTR_MASK      (0x01u) 
#endif /* (pwmop__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define pwmop_PS                     (* (reg8 *) pwmop__PS)
/* Data Register */
#define pwmop_DR                     (* (reg8 *) pwmop__DR)
/* Port Number */
#define pwmop_PRT_NUM                (* (reg8 *) pwmop__PRT) 
/* Connect to Analog Globals */                                                  
#define pwmop_AG                     (* (reg8 *) pwmop__AG)                       
/* Analog MUX bux enable */
#define pwmop_AMUX                   (* (reg8 *) pwmop__AMUX) 
/* Bidirectional Enable */                                                        
#define pwmop_BIE                    (* (reg8 *) pwmop__BIE)
/* Bit-mask for Aliased Register Access */
#define pwmop_BIT_MASK               (* (reg8 *) pwmop__BIT_MASK)
/* Bypass Enable */
#define pwmop_BYP                    (* (reg8 *) pwmop__BYP)
/* Port wide control signals */                                                   
#define pwmop_CTL                    (* (reg8 *) pwmop__CTL)
/* Drive Modes */
#define pwmop_DM0                    (* (reg8 *) pwmop__DM0) 
#define pwmop_DM1                    (* (reg8 *) pwmop__DM1)
#define pwmop_DM2                    (* (reg8 *) pwmop__DM2) 
/* Input Buffer Disable Override */
#define pwmop_INP_DIS                (* (reg8 *) pwmop__INP_DIS)
/* LCD Common or Segment Drive */
#define pwmop_LCD_COM_SEG            (* (reg8 *) pwmop__LCD_COM_SEG)
/* Enable Segment LCD */
#define pwmop_LCD_EN                 (* (reg8 *) pwmop__LCD_EN)
/* Slew Rate Control */
#define pwmop_SLW                    (* (reg8 *) pwmop__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define pwmop_PRTDSI__CAPS_SEL       (* (reg8 *) pwmop__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define pwmop_PRTDSI__DBL_SYNC_IN    (* (reg8 *) pwmop__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define pwmop_PRTDSI__OE_SEL0        (* (reg8 *) pwmop__PRTDSI__OE_SEL0) 
#define pwmop_PRTDSI__OE_SEL1        (* (reg8 *) pwmop__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define pwmop_PRTDSI__OUT_SEL0       (* (reg8 *) pwmop__PRTDSI__OUT_SEL0) 
#define pwmop_PRTDSI__OUT_SEL1       (* (reg8 *) pwmop__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define pwmop_PRTDSI__SYNC_OUT       (* (reg8 *) pwmop__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(pwmop__SIO_CFG)
    #define pwmop_SIO_HYST_EN        (* (reg8 *) pwmop__SIO_HYST_EN)
    #define pwmop_SIO_REG_HIFREQ     (* (reg8 *) pwmop__SIO_REG_HIFREQ)
    #define pwmop_SIO_CFG            (* (reg8 *) pwmop__SIO_CFG)
    #define pwmop_SIO_DIFF           (* (reg8 *) pwmop__SIO_DIFF)
#endif /* (pwmop__SIO_CFG) */

/* Interrupt Registers */
#if defined(pwmop__INTSTAT)
    #define pwmop_INTSTAT            (* (reg8 *) pwmop__INTSTAT)
    #define pwmop_SNAP               (* (reg8 *) pwmop__SNAP)
    
	#define pwmop_0_INTTYPE_REG 		(* (reg8 *) pwmop__0__INTTYPE)
#endif /* (pwmop__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_pwmop_H */


/* [] END OF FILE */
